@@ -90,9 +90,8 @@ public:
 
     virtual void activeCachePolicy(Collection &col) Q_DECL_OVERRIDE;
 
-    virtual bool appendMimeType(const QString &mimetype,
-                                qint64 *insertId = Q_NULLPTR) Q_DECL_OVERRIDE;
     virtual bool appendPimItem(QVector<Part> &parts,
+                               const QVector<Flag> &flags,
                                const MimeType &mimetype,
                                const Collection &collection,
                                const QDateTime &dateTime,
