@@ -25,7 +25,7 @@
 #include "servermanager.h"
 #include "servermanager_p.h"
 #include "protocolhelper_p.h"
-#include "connectionthread_p.h"
+#include "sessionthread_p.h"
 #include "private/standarddirs_p.h"
 #include "private/protocol_p.h"
 
@@ -34,16 +34,16 @@
 #include <KLocalizedString>
 
 #include <QCoreApplication>
-#include <QtCore/QDir>
-#include <QtCore/QQueue>
-#include <QtCore/QThreadStorage>
-#include <QtCore/QTimer>
-#include <QtCore/QThread>
+#include <QDir>
+#include <QQueue>
+#include <QThreadStorage>
+#include <QTimer>
+#include <QThread>
 #include <QSettings>
 
-#include <QtNetwork/QLocalSocket>
-#include <QtNetwork/QTcpSocket>
-#include <QtNetwork/QHostAddress>
+#include <QLocalSocket>
+#include <QTcpSocket>
+#include <QHostAddress>
 #include <QApplication>
 
 // ### FIXME pipelining got broken by switching result emission in JobPrivate::handleResponse to delayed emission
@@ -63,21 +63,20 @@ void SessionPrivate::startNext()
 
 void SessionPrivate::reconnect()
 {
-    if (!connThread) {
-        connThread = new ConnectionThread(sessionId);
-        mParent->connect(connThread, &ConnectionThread::reconnected, mParent, &Session::reconnected,
-                        Qt::QueuedConnection);
-        mParent->connect(connThread, SIGNAL(commandReceived(qint64,Akonadi::Protocol::Command)),
-                        mParent, SLOT(handleCommand(qint64, Akonadi::Protocol::Command)),
-                        Qt::QueuedConnection);
-        mParent->connect(connThread, SIGNAL(socketDisconnected()), mParent, SLOT(socketDisconnected()),
-                        Qt::QueuedConnection);
-        mParent->connect(connThread, SIGNAL(socketError(QString)), mParent, SLOT(socketError(QString)),
-                        Qt::QueuedConnection);
-
+    if (!connection) {
+        connection = sessionThread()->createConnection(Connection::CommandConnection, sessionId);
+        mParent->connect(connection, &Connection::reconnected, mParent, &Session::reconnected,
+                         Qt::QueuedConnection);
+        mParent->connect(connection, SIGNAL(commandReceived(qint64,Akonadi::Protocol::Command)),
+                         mParent, SLOT(handleCommand(qint64,Akonadi::Protocol::Command)),
+                         Qt::QueuedConnection);
+        mParent->connect(connection, SIGNAL(socketDisconnected()), mParent, SLOT(socketDisconnected()),
+                         Qt::QueuedConnection);
+        mParent->connect(connection, SIGNAL(socketError(QString)), mParent, SLOT(socketError(QString)),
+                         Qt::QueuedConnection);
     }
 
-    connThread->reconnect();
+    connection->reconnect();
 }
 
 QString SessionPrivate::connectionFile()
@@ -106,17 +105,20 @@ bool SessionPrivate::handleCommand(qint64 tag, const Protocol::Command &cmd)
         Protocol::HelloResponse hello(cmd);
         if (hello.isError()) {
             qCWarning(AKONADICORE_LOG) << "Error when establishing connection with Akonadi server:" << hello.errorMessage();
-            connThread->disconnect();
-            QTimer::singleShot(1000, connThread, &ConnectionThread::reconnect);
+            connection->closeConnection();
+            QTimer::singleShot(1000, connection, &Connection::reconnect);
             return false;
         }
 
         qCDebug(AKONADICORE_LOG) << "Connected to" << hello.serverName() << ", using protocol version" << hello.protocolVersion();
+        qCDebug(AKONADICORE_LOG) << "Server generation:" << hello.generation();
         qCDebug(AKONADICORE_LOG) << "Server says:" << hello.message();
         // Version mismatch is handled in SessionPrivate::startJob() so that
         // we can report the error out via KJob API
         protocolVersion = hello.protocolVersion();
         Internal::setServerProtocolVersion(protocolVersion);
+        Internal::setGeneration(hello.generation());
+
 
         Protocol::LoginCommand login(sessionId);
         sendCommand(nextTag(), login);
@@ -128,7 +130,7 @@ bool SessionPrivate::handleCommand(qint64 tag, const Protocol::Command &cmd)
         Protocol::LoginResponse login(cmd);
         if (login.isError()) {
             qCWarning(AKONADICORE_LOG) << "Unable to login to Akonadi server:" << login.errorMessage();
-            connThread->disconnect();
+            connection->closeConnection();
             QTimer::singleShot(1000, mParent, SLOT(reconnect()));
             return false;
         }
@@ -260,12 +262,11 @@ qint64 SessionPrivate::nextTag()
 
 void SessionPrivate::sendCommand(qint64 tag, const Protocol::Command &command)
 {
-    connThread->sendCommand(tag, command);
+    connection->sendCommand(tag, command);
 }
 
 void SessionPrivate::serverStateChanged(ServerManager::State state)
 {
-    qCDebug(AKONADICORE_LOG) << "============== SESSION: Server state changed to " << state;
     if (state == ServerManager::Running && !connected) {
         reconnect();
     } else if (!connected && state == ServerManager::Broken) {
@@ -276,8 +277,8 @@ void SessionPrivate::serverStateChanged(ServerManager::State state)
             job->kill(KJob::EmitResult);
         }
     } else if (state == ServerManager::Stopping) {
-        delete connThread;
-        connThread = Q_NULLPTR;
+        delete connection;
+        connection = Q_NULLPTR;
     }
 }
 
@@ -294,25 +295,25 @@ void SessionPrivate::itemRevisionChanged(Akonadi::Item::Id itemId, int oldRevisi
 
 SessionPrivate::SessionPrivate(Session *parent)
     : mParent(parent)
-    , thread(0)
-    , connThread(0)
+    , mSessionThread(new SessionThread)
+    , connection(Q_NULLPTR)
     , protocolVersion(0)
-    , currentJob(0)
+    , currentJob(Q_NULLPTR)
 {
     // Shutdown the thread before QApplication event loop quits - the
-    // thread()->wait() mechanism in ConnectionThread dtor crashes sometimes
+    // thread()->wait() mechanism in Connection dtor crashes sometimes
     // when called from QApplication destructor
     connThreadCleanUp = QObject::connect(qApp, &QCoreApplication::aboutToQuit,
                                          [this]() {
-                                             delete connThread;
-                                             connThread = Q_NULLPTR;
+                                             delete mSessionThread;
+                                             mSessionThread = Q_NULLPTR;
                                          });
 }
 
 SessionPrivate::~SessionPrivate()
 {
     QObject::disconnect(connThreadCleanUp);
-    delete connThread;
+    delete mSessionThread;
 }
 
 void SessionPrivate::init(const QByteArray &id)
@@ -342,8 +343,8 @@ void SessionPrivate::forceReconnect()
 {
     jobRunning = false;
     connected = false;
-    if (connThread) {
-        connThread->forceReconnect();
+    if (connection) {
+        connection->forceReconnect();
     }
     QMetaObject::invokeMethod(mParent, "reconnect", Qt::QueuedConnection);
 }
