@@ -20,11 +20,11 @@
 #ifndef AKONADI_CONNECTION_H
 #define AKONADI_CONNECTION_H
 
-#include <QtCore/QPointer>
-#include <QtCore/QThread>
-#include <QtCore/QTimer>
-#include <QtNetwork/QLocalSocket>
-#include <QtCore/QDataStream>
+#include <QPointer>
+#include <QThread>
+#include <QTimer>
+#include <QLocalSocket>
+#include <QDataStream>
 
 #include "akthread.h"
 #include "entities.h"
@@ -49,7 +49,7 @@ class Connection : public AkThread
 {
     Q_OBJECT
 public:
-    Connection(quintptr socketDescriptor, QObject *parent = Q_NULLPTR);
+    explicit Connection(quintptr socketDescriptor, QObject *parent = Q_NULLPTR);
     virtual ~Connection();
 
     virtual DataStore *storageBackend();
@@ -67,13 +67,9 @@ public:
     void setSessionId(const QByteArray &id);
     QByteArray sessionId() const;
 
-    void setIsNotificationBus(bool on);
-    bool isNotificationBus() const;
-
     /** Returns @c true if permanent cache verification is enabled. */
     bool verifyCacheOnRetrieval() const;
 
-
     Protocol::Command readCommand();
 
 public Q_SLOTS:
@@ -105,7 +101,6 @@ protected:
     QLocalSocket *m_socket;
     QPointer<Handler> m_currentHandler;
     ConnectionState m_connectionState;
-    bool m_isNotificationBus;
     mutable DataStore *m_backend;
     QList<QByteArray> m_statusMessageQueue;
     QString m_identifier;
