@@ -39,7 +39,7 @@ class  ResourceSelect : public Handler
 {
     Q_OBJECT
 public:
-    bool parseStream();
+    bool parseStream() Q_DECL_OVERRIDE;
 };
 
 } // namespace Server
