@@ -96,7 +96,7 @@ class Store : public Handler
     Q_OBJECT
 
 public:
-    bool parseStream();
+    bool parseStream() Q_DECL_OVERRIDE;
 
 private:
     bool replaceFlags(const PimItem::List &items, const QSet<QByteArray> &flags, bool &flagsChanged);
