@@ -39,8 +39,23 @@ using namespace Akonadi::Server;
 
 ItemRetrievalManager *ItemRetrievalManager::sInstance = 0;
 
+class ItemRetrievalJobFactory : public AbstractItemRetrievalJobFactory
+{
+    AbstractItemRetrievalJob *retrievalJob(ItemRetrievalRequest *request, QObject *parent) Q_DECL_OVERRIDE
+    {
+        return new ItemRetrievalJob(request, parent);
+    }
+};
+
+
 ItemRetrievalManager::ItemRetrievalManager(QObject *parent)
+    : ItemRetrievalManager(new ItemRetrievalJobFactory, parent)
+{
+}
+
+ItemRetrievalManager::ItemRetrievalManager(AbstractItemRetrievalJobFactory *factory, QObject *parent)
     : AkThread(QThread::HighPriority, parent)
+    , mJobFactory(factory)
 {
     qDBusRegisterMetaType<QByteArrayList>();
 
@@ -126,30 +141,17 @@ org::freedesktop::Akonadi::Resource *ItemRetrievalManager::resourceInterface(con
 }
 
 // called from any thread
-void ItemRetrievalManager::requestItemDelivery(qint64 uid, const QByteArray &remoteId, const QByteArray &mimeType,
-                                               const QString &resource, const QVector<QByteArray> &parts)
-{
-    ItemRetrievalRequest *req = new ItemRetrievalRequest();
-    req->id = uid;
-    req->remoteId = QString::fromUtf8(remoteId);
-    req->mimeType = QString::fromUtf8(mimeType);
-    req->resourceId = resource;
-    req->parts = parts.toList();
-
-    requestItemDelivery(req);
-}
-
 void ItemRetrievalManager::requestItemDelivery(ItemRetrievalRequest *req)
 {
     mLock->lockForWrite();
-    qCDebug(AKONADISERVER_LOG) << "posting retrieval request for item" << req->id << " there are "
+    qCDebug(AKONADISERVER_LOG) << "posting retrieval request for items" << req->ids << " there are "
               << mPendingRequests.size() << " queues and "
               << mPendingRequests[req->resourceId].size() << " items in mine";
     mPendingRequests[req->resourceId].append(req);
     mLock->unlock();
 
     Q_EMIT requestAdded();
-
+#if 0
     mLock->lockForRead();
     Q_FOREVER {
         //qCDebug(AKONADISERVER_LOG) << "checking if request for item" << req->id << "has been processed...";
@@ -159,30 +161,30 @@ void ItemRetrievalManager::requestItemDelivery(ItemRetrievalRequest *req)
             const QString errorMsg = req->errorMsg;
             mLock->unlock();
             if (errorMsg.isEmpty()) {
-                qCDebug(AKONADISERVER_LOG) << "request for item" << req->id << "succeeded";
+                qCDebug(AKONADISERVER_LOG) << "request for items" << req->ids << "succeeded";
                 return;
             } else {
-                qCDebug(AKONADISERVER_LOG) << "request for item" << req->id << req->remoteId << "failed:" << errorMsg;
+                qCDebug(AKONADISERVER_LOG) << "request for items" << req->ids << "failed:" << errorMsg;
                 throw ItemRetrieverException(errorMsg);
             }
         } else {
-            qCDebug(AKONADISERVER_LOG) << "request for item" << req->id << "still pending - waiting";
+            qCDebug(AKONADISERVER_LOG) << "request for items" << req->ids << "still pending - waiting";
             mWaitCondition->wait(mLock);
             qCDebug(AKONADISERVER_LOG) << "continuing";
         }
     }
 
     throw ItemRetrieverException("WTF?");
+#endif
 }
 
 // called within the retrieval thread
 void ItemRetrievalManager::processRequest()
 {
-    QVector<QPair<ItemRetrievalJob *, QString> > newJobs;
-
+    QVector<QPair<AbstractItemRetrievalJob *, QString> > newJobs;
     mLock->lockForWrite();
     // look for idle resources
-    for (QHash< QString, QList< ItemRetrievalRequest *> >::iterator it = mPendingRequests.begin(); it != mPendingRequests.end();) {
+    for (auto it = mPendingRequests.begin(); it != mPendingRequests.end();) {
         if (it.value().isEmpty()) {
             it = mPendingRequests.erase(it);
             continue;
@@ -191,11 +193,12 @@ void ItemRetrievalManager::processRequest()
             // TODO: check if there is another one for the same uid with more parts requested
             ItemRetrievalRequest *req = it.value().takeFirst();
             Q_ASSERT(req->resourceId == it.key());
-            ItemRetrievalJob *job = new ItemRetrievalJob(req, this);
-            connect(job, &ItemRetrievalJob::requestCompleted, this, &ItemRetrievalManager::retrievalJobFinished);
+            AbstractItemRetrievalJob *job = mJobFactory->retrievalJob(req, this);
+            connect(job, &AbstractItemRetrievalJob::requestCompleted, this, &ItemRetrievalManager::retrievalJobFinished);
             mCurrentJobs.insert(req->resourceId, job);
             // delay job execution until after we unlocked the mutex, since the job can emit the finished signal immediately in some cases
             newJobs.append(qMakePair(job, req->resourceId));
+            qCDebug(AKONADISERVER_LOG) << "ItemRetrievalJob" << job << "started for request" << req;
         }
         ++it;
     }
@@ -204,17 +207,20 @@ void ItemRetrievalManager::processRequest()
     mLock->unlock();
 
     if (nothingGoingOn) {   // someone asked as to process requests although everything is done already, he might still be waiting
-        mWaitCondition->wakeAll();
         return;
     }
 
-    for (QVector<QPair<ItemRetrievalJob *, QString> >::const_iterator it = newJobs.constBegin(); it != newJobs.constEnd(); ++it) {
-        (*it).first->start(resourceInterface((*it).second));
+    for (auto it = newJobs.constBegin(), end = newJobs.constEnd(); it != end; ++it) {
+        if (ItemRetrievalJob *j = qobject_cast<ItemRetrievalJob*>((*it).first)) {
+            j->setInterface(resourceInterface((*it).second));
+        }
+        (*it).first->start();
     }
 }
 
 void ItemRetrievalManager::retrievalJobFinished(ItemRetrievalRequest *request, const QString &errorMsg)
 {
+    qCDebug(AKONADISERVER_LOG) << "ItemRetrievalJob finished for request" << request << ", error:" << errorMsg;
     mLock->lockForWrite();
     request->errorMsg = errorMsg;
     request->processed = true;
@@ -222,8 +228,8 @@ void ItemRetrievalManager::retrievalJobFinished(ItemRetrievalRequest *request, c
     mCurrentJobs.remove(request->resourceId);
     // TODO check if (*it)->parts is a subset of currentRequest->parts
     for (QList<ItemRetrievalRequest *>::Iterator it = mPendingRequests[request->resourceId].begin(); it != mPendingRequests[request->resourceId].end();) {
-        if ((*it)->id == request->id) {
-            qCDebug(AKONADISERVER_LOG) << "someone else requested item" << request->id << "as well, marking as processed";
+        if ((*it)->ids == request->ids) {
+            qCDebug(AKONADISERVER_LOG) << "someone else requested item" << request->ids << "as well, marking as processed";
             (*it)->errorMsg = errorMsg;
             (*it)->processed = true;
             it = mPendingRequests[request->resourceId].erase(it);
@@ -231,8 +237,8 @@ void ItemRetrievalManager::retrievalJobFinished(ItemRetrievalRequest *request, c
             ++it;
         }
     }
-    mWaitCondition->wakeAll();
     mLock->unlock();
+    Q_EMIT requestFinished(request);
     Q_EMIT requestAdded(); // trigger processRequest() again, in case there is more in the queues
 }
 
