@@ -38,27 +38,36 @@ namespace Server {
 class Collection;
 class ItemRetrievalJob;
 class ItemRetrievalRequest;
+class AbstractItemRetrievalJob;
+
+class AbstractItemRetrievalJobFactory
+{
+public:
+    explicit AbstractItemRetrievalJobFactory() {}
+    virtual ~AbstractItemRetrievalJobFactory() {}
+
+    virtual AbstractItemRetrievalJob *retrievalJob(ItemRetrievalRequest *request, QObject *parent) = 0;
+};
 
 /** Manages and processes item retrieval requests. */
 class ItemRetrievalManager : public AkThread
 {
     Q_OBJECT
 public:
-    ItemRetrievalManager(QObject *parent = Q_NULLPTR);
+    explicit ItemRetrievalManager(QObject *parent = Q_NULLPTR);
+    explicit ItemRetrievalManager(AbstractItemRetrievalJobFactory *factory, QObject *parent = Q_NULLPTR);
     ~ItemRetrievalManager();
 
-    void requestItemDelivery(qint64 uid, const QByteArray &remoteId, const QByteArray &mimeType,
-                             const QString &resource, const QVector<QByteArray> &parts);
-
     /**
      * Added for convenience. ItemRetrievalManager takes ownership over the
      * pointer and deletes it when the request is processed.
      */
-    void requestItemDelivery(ItemRetrievalRequest *request);
+    virtual void requestItemDelivery(ItemRetrievalRequest *request);
 
     static ItemRetrievalManager *instance();
 
 Q_SIGNALS:
+    void requestFinished(ItemRetrievalRequest *request);
     void requestAdded();
 
 private:
@@ -73,8 +82,11 @@ private Q_SLOTS:
     void triggerCollectionTreeSync(const QString &resource);
     void retrievalJobFinished(ItemRetrievalRequest *request, const QString &errorMsg);
 
-private:
+protected:
     static ItemRetrievalManager *sInstance;
+
+    AbstractItemRetrievalJobFactory *mJobFactory;
+
     /// Protects mPendingRequests and every Request object posted to it
     QReadWriteLock *mLock;
     /// Used to let requesting threads wait until the request has been processed
@@ -82,7 +94,7 @@ private:
     /// Pending requests queues, one per resource
     QHash<QString, QList<ItemRetrievalRequest *> > mPendingRequests;
     /// Currently running jobs, one per resource
-    QHash<QString, ItemRetrievalJob *> mCurrentJobs;
+    QHash<QString, AbstractItemRetrievalJob *> mCurrentJobs;
 
     // resource dbus interface cache
     QHash<QString, OrgFreedesktopAkonadiResourceInterface *> mResourceInterfaces;
