@@ -24,10 +24,10 @@
 
 #include <private/protocol_p.h>
 
-#include <QtCore/QByteArray>
-#include <QtCore/QList>
-#include <QtCore/QObject>
-#include <QtCore/QString>
+#include <QByteArray>
+#include <QList>
+#include <QObject>
+#include <QString>
 
 namespace Akonadi {
 namespace Server {
@@ -48,13 +48,13 @@ public:
       Create a new notification collector that is not attached to
       a DataStore and just collects notifications until you emit them manually.
     */
-    NotificationCollector(QObject *parent = Q_NULLPTR);
+    explicit NotificationCollector(QObject *parent = Q_NULLPTR);
 
     /**
       Create a new notification collector for the given DataStore @p db.
       @param db The datastore using this notification collector.
     */
-    NotificationCollector(DataStore *db);
+    explicit NotificationCollector(DataStore *db);
 
     /**
       Destroys this notification collector.
@@ -71,7 +71,8 @@ public:
       Provide as many parameters as you have at hand currently, everything
       that is missing will be looked up in the database later.
     */
-    void itemAdded(const PimItem &item, const Collection &collection = Collection(),
+    void itemAdded(const PimItem &item, bool seen,
+                   const Collection &collection = Collection(),
                    const QByteArray &resource = QByteArray());
 
     /**
@@ -220,7 +221,8 @@ Q_SIGNALS:
     void notify(const Akonadi::Protocol::ChangeNotification::List &msgs);
 
 private:
-    void itemNotification(Protocol::ChangeNotification::Operation op, const PimItem::List &items,
+    void itemNotification(Protocol::ItemChangeNotification::Operation op,
+                          const PimItem::List &items,
                           const Collection &collection,
                           const Collection &collectionDest,
                           const QByteArray &resource,
@@ -231,23 +233,24 @@ private:
                           const QSet<qint64> &removedTags = QSet<qint64>(),
                           const Relation::List &addedRelations = Relation::List(),
                           const Relation::List &removedRelations = Relation::List() );
-    void itemNotification(Protocol::ChangeNotification::Operation op, const PimItem &item,
+    void itemNotification(Protocol::ItemChangeNotification::Operation op,
+                          const PimItem &item,
                           const Collection &collection,
                           const Collection &collectionDest,
                           const QByteArray &resource,
                           const QSet<QByteArray> &parts = QSet<QByteArray>());
-    void collectionNotification(Protocol::ChangeNotification::Operation op,
+    void collectionNotification(Protocol::CollectionChangeNotification::Operation op,
                                 const Collection &collection,
                                 Collection::Id source, Collection::Id destination,
                                 const QByteArray &resource,
                                 const QSet<QByteArray> &changes = QSet<QByteArray>(),
                                 const QByteArray &destResource = QByteArray());
-    void tagNotification(Protocol::ChangeNotification::Operation op,
+    void tagNotification(Protocol::TagChangeNotification::Operation op,
                           const Tag &tag,
                           const QByteArray &resource = QByteArray(),
                           const QString &remoteId = QString());
-    void relationNotification(Protocol::ChangeNotification::Operation op,
-                                             const Relation &relation);
+    void relationNotification(Protocol::RelationChangeNotification::Operation op,
+                              const Relation &relation);
     void dispatchNotification(const Protocol::ChangeNotification &msg);
     void clear();
 
