@@ -22,7 +22,6 @@
 */
 
 #include "akdebug.h"
-#include "akcrash.h"
 
 #include <private/standarddirs_p.h>
 
@@ -32,10 +31,13 @@
 #include <QMutex>
 #include <QLoggingCategory>
 
+#include <KCrash/KCrash>
+
 #include <cassert>
 
 class FileDebugStream : public QIODevice
 {
+    Q_OBJECT
 public:
     FileDebugStream()
         : mType(QtCriticalMsg)
@@ -171,7 +173,7 @@ void akMessageHandler(QtMsgType type, const QMessageLogContext &context, const Q
 void akCategoryFilter(QLoggingCategory *category)
 {
     if ((qstrcmp(category->categoryName(), sInstance()->loggingCategory) == 0) ||
-        (qstrcmp(category->categoryName(), "akonadiprivate_log") == 0)) {
+        (qstrcmp(category->categoryName(), "org.kde.pim.akonadiprivate") == 0)) {
         category->setEnabled(QtDebugMsg, true);
         category->setEnabled(QtInfoMsg, true);
         category->setEnabled(QtWarningMsg, true);
@@ -184,7 +186,7 @@ void akCategoryFilter(QLoggingCategory *category)
 
 void akInit(const QString &appName)
 {
-    AkonadiCrash::init();
+    KCrash::initialize();
     sInstance()->setName(appName);
 
     QFileInfo infoOld(sInstance()->errorLogFileName() + QLatin1String(".old"));
@@ -214,3 +216,6 @@ void akMakeVerbose(const QByteArray &category)
     QLoggingCategory::CategoryFilter oldFilter = QLoggingCategory::installFilter(akCategoryFilter);
     sInstance()->setOrigCategoryFilter(oldFilter);
 }
+
+#include "akdebug.moc"
+
